/*

  Open Smart TFT LCD 3.2" Touchscreen

  Parts required:
  - Arduino Board
  - Open Smart TFT LCD 3.2" Touchscreen

  Libraries required:
  - MCUFRIEND_kbv
  - Adafruit GFX
  - Adafruit TouchScreen

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 16 Jun 2019
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <MCUFRIEND_kbv.h>
MCUFRIEND_kbv tft;

// Initialize all variables
int delayTimer = 3000;
int screenSizeX;
int screenSizeY;

void setup() {
  tft.begin(0x9327);                                                        // Initialize screen
}

void loop() {
  show_logo();                                                              // Start functions
  show_screen_size();
  draw_circles_empty();
  draw_circles_filled();
  draw_lines_diogonal();
}

void show_screen_size() {

  for (int i = 1; i <= 4; i++) {                                            // For i = 1 to 4 Do

    tft.setRotation(i);                                                     // Set rotation for Horisontal
    tft.fillScreen(0x0000);                                                 // Set screen color to black

    screenSizeX = tft.width();                                              // Read the screen width and store in screenSizeX
    screenSizeY = tft.height();                                             // Read the screen height and store in screenSizeY

    tft.drawRect(0, 0, screenSizeX, screenSizeY, 0x07FF);                   // Draw a rectangle 

    tft.drawLine(0, 0, screenSizeX, screenSizeY, 0xFFE0);                   // Draw a line
    tft.drawLine(0, screenSizeY, screenSizeX, 0, 0xFFE0);                   // Draw a line

    tft.setCursor((screenSizeX / 2) - 15, 10);                              // Set cursor to position middle screen - text size
    tft.setTextSize(2);                                                     // Set text size as 2
    tft.setTextColor(0xFFFF);                                               // Set text color as white
    tft.println(screenSizeX);                                               // Print screen size to screen

    tft.setCursor(screenSizeX - 45, (screenSizeY / 2) - 10);                // Set cursor to position middle screen - text size
    tft.setTextSize(2);                                                     // Set text size as 2
    tft.setTextColor(0xFFFF);                                               // Set text color as white
    tft.println(screenSizeY);                                               // Print screen size to screen
    delay(delayTimer - 1000);                                               // Delay
    tft.fillScreen(0x0000);                                                 // Clear screen with black color
    tft.setRotation(1);                                                     // Set screen rotation to normal
  }
}

void show_logo() {
  tft.fillScreen(1100);                                                     // Set screen color to Arduinotech.dk's color
  tft.setRotation(1);                                                       // Set screen rotation to normal
  tft.setTextColor(0xFFFF);                                                 // Set text color to white
  tft.setTextSize(3);                                                       // Set text size to 3
  tft.setCursor(210, 90);                                                   // Set cursor position to X,Y
  tft.println("ARDUINO");                                                   // Print text
  tft.setCursor(210, 120);                                                  // Set cursor position to X,Y
  tft.println("TECH.DK");                                                   // Print text

  for (int i = 0; i <= 2; i++) {                                            // For i = 0 to 2 Do
    tft.drawLine(129 + i, 80, 129 + i, 150, 0xFFFF);                        // Draw a line
    tft.drawLine(60, 114 + i, 200, 114 + i, 0xFFFF);                        // Draw a line
  }

  for (int i = 20; i <= 28; i++) {                                          // For i = 20 to 28 Do
    tft.drawCircle(105, 115, i, 0xFFFF);                                    // Draw a circle
    tft.drawCircle(155, 115, i, 0xFFFF);                                    // Draw a circle
  }
  delay(delayTimer);                                                        // Delay
  tft.fillScreen(0x0000);                                                   // Clear screen with black color
}

void draw_circles_empty() {
  for (int i = 0; i <= 200; i++) {                                          // For i = 0 to 200 Do
    tft.drawCircle(random(400), random(240), random(100), random(65535));   // Draw circle in random size
  }
  delay(delayTimer);                                                        // Delay
  tft.fillScreen(0x0000);                                                   // Clear screen with black color
}

void draw_circles_filled() {
  for (int i = 0; i <= 200; i++) {
    tft.fillCircle(random(400), random(240), random(100), random(65535));   // Draw filled circle in random size
  }

  delay(delayTimer);                                                        // Delay
  tft.fillScreen(0x0000);                                                   // Clear screen with black color
}

void draw_lines_diogonal() {
  for (int j = 1000; j <= 9000; j = j + 1000) {                             // For j = 1000 to 9000 step 1000 Do
    for (int i = 0; i <= 400; i = i + 10) {                                 // For i = 0 to 400 step 10 Do
      tft.drawLine(i, 0, 0, 240, j);                                        // Draw lines
    }

    for (int i = 0; i <= 400; i = i + 10) {                                 // For i = 0 to 400 step 10 Do
      tft.drawLine(400, 0, i, 240, j);                                      // Draw lines
    }
  }
  delay(delayTimer);                                                        // Delay
  tft.fillScreen(0x0000);                                                   // Clear screen with black color
}
